@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci.h,v 1.35 2004/04/25 19:06:24 holtmann Exp $
+ *  $Id: hci.h,v 1.44 2004/11/09 22:52:40 holtmann Exp $
  */
 
 #ifndef __HCI_H
@@ -70,7 +70,9 @@ enum {
 	HCI_ENCRYPT,
 	HCI_INQUIRY,
 
-	HCI_RAW
+	HCI_RAW,
+
+	HCI_SECMGR
 };
 
 /* HCI ioctl defines */
@@ -94,6 +96,8 @@ enum {
 #define HCISETACLMTU	_IOW('H', 227, int)
 #define HCISETSCOMTU	_IOW('H', 228, int)
 
+#define HCISETSECMGR	_IOW('H', 230, int)
+
 #define HCIINQUIRY	_IOR('H', 240, int)
 
 /* HCI timeouts */
@@ -109,7 +113,7 @@ enum {
 #define HCI_ACLDATA_PKT		0x02
 #define HCI_SCODATA_PKT		0x03
 #define HCI_EVENT_PKT		0x04
-#define HCI_UNKNOWN_PKT		0xff
+#define HCI_VENDOR_PKT		0xff
 
 /* HCI Packet types */
 #define HCI_2DH1	0x0002
@@ -146,7 +150,7 @@ enum {
 #define HCI_HARDWARE_FAILURE			0x03
 #define HCI_PAGE_TIMEOUT			0x04
 #define HCI_AUTHENTICATION_FAILURE		0x05
-#define HCI_KEY_MISSING				0x06
+#define HCI_PIN_OR_KEY_MISSING			0x06
 #define HCI_MEMORY_FULL				0x07
 #define HCI_CONNECTION_TIMEOUT			0x08
 #define HCI_MAX_NUMBER_OF_CONNECTIONS		0x09
@@ -182,6 +186,15 @@ enum {
 #define HCI_QOS_NOT_SUPPORTED			0x27
 #define HCI_INSTANT_PASSED			0x28
 #define HCI_PAIRING_NOT_SUPPORTED		0x29
+#define HCI_TRANSACTION_COLLISION		0x2a
+#define HCI_QOS_UNACCEPTABLE_PARAMETER		0x2c
+#define HCI_QOS_REJECTED			0x2d
+#define HCI_CLASSIFICATION_NOT_SUPPORTED	0x2e
+#define HCI_INSUFFICIENT_SECURITY		0x2f
+#define HCI_PARAMETER_OUT_OF_RANGE		0x30
+#define HCI_ROLE_SWITCH_PENDING			0x32
+#define HCI_SLOT_VIOLATION			0x34
+#define HCI_ROLE_SWITCH_FAILED			0x35
 
 /* ACL flags */
 #define ACL_CONT		0x01
@@ -254,6 +267,7 @@ enum {
 #define HCI_LM_ENCRYPT	0x0004
 #define HCI_LM_TRUSTED	0x0008
 #define HCI_LM_RELIABLE	0x0010
+#define HCI_LM_SECURE	0x0020
 
 /* -----  HCI Commands ----- */
 
@@ -366,6 +380,12 @@ typedef struct {
 } __attribute__ ((packed)) set_conn_encrypt_cp;
 #define SET_CONN_ENCRYPT_CP_SIZE 3
 
+#define OCF_CHANGE_CONN_LINK_KEY	0x0015
+typedef struct {
+	uint16_t	handle;
+} __attribute__ ((packed)) change_conn_link_key_cp;
+#define CHANGE_CONN_LINK_KEY_CP_SIZE 2
+
 #define OCF_REMOTE_NAME_REQ		0x0019
 typedef struct {
 	bdaddr_t	bdaddr;
@@ -674,6 +694,16 @@ typedef struct {
 } __attribute__ ((packed)) write_current_iac_lap_cp;
 #define WRITE_CURRENT_IAC_LAP_CP_SIZE 1+3*MAX_IAC_LAP
 
+#define OCF_SET_AFH_CLASSIFICATION	0x003F
+typedef struct {
+	uint8_t		map[10];
+} __attribute__ ((packed)) set_afh_classification_cp;
+#define SET_AFH_CLASSIFICATION_CP_SIZE 10
+typedef struct {
+	uint8_t		status;
+} __attribute__ ((packed)) set_afh_classification_rp;
+#define SET_AFH_CLASSIFICATION_RP_SIZE 1
+
 #define OCF_READ_INQUIRY_MODE		0x0044
 typedef struct {
 	uint8_t		status;
@@ -856,6 +886,13 @@ typedef struct {
 } __attribute__ ((packed)) evt_encrypt_change;
 #define EVT_ENCRYPT_CHANGE_SIZE 5
 
+#define EVT_CHANGE_CONN_LINK_KEY_COMPLETE	0x09
+typedef struct {
+	uint8_t		status;
+	uint16_t	handle;
+}  __attribute__ ((packed)) evt_change_conn_link_key_complete;
+#define EVT_CHANGE_CONN_LINK_KEY_COMPLETE_SIZE 3
+
 #define EVT_READ_REMOTE_FEATURES_COMPLETE	0x0B
 typedef struct {
 	uint8_t		status;
@@ -964,14 +1001,14 @@ typedef struct {
 } __attribute__ ((packed)) evt_qos_violation;
 #define EVT_QOS_VIOLATION_SIZE 2
 
-#define EVT_INQUIRY_RESULT_WITH_RSSI	0x02
+#define EVT_INQUIRY_RESULT_WITH_RSSI	0x22
 typedef struct {
 	bdaddr_t	bdaddr;
 	uint8_t		pscan_rep_mode;
 	uint8_t		pscan_period_mode;
 	uint8_t		dev_class[3];
 	uint16_t	clock_offset;
-	uint8_t		rssi;
+	int8_t		rssi;
 } __attribute__ ((packed)) inquiry_info_with_rssi;
 #define INQUIRY_INFO_WITH_RSSI_SIZE 14
 
