@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: l2cap.h,v 1.4 2004/04/03 05:11:38 holtmann Exp $
+ *  $Id: l2cap.h,v 1.8 2004/11/09 12:46:35 holtmann Exp $
  */
 
 #ifndef __L2CAP_H
@@ -48,7 +48,7 @@ struct sockaddr_l2 {
 	bdaddr_t	l2_bdaddr;
 };
 
-/* Socket options */
+/* L2CAP socket options */
 #define L2CAP_OPTIONS	0x01
 struct l2cap_options {
 	uint16_t omtu;
@@ -67,6 +67,7 @@ struct l2cap_conninfo {
 #define L2CAP_LM_ENCRYPT	0x0004
 #define L2CAP_LM_TRUSTED	0x0008
 #define L2CAP_LM_RELIABLE	0x0010
+#define L2CAP_LM_SECURE		0x0020
 
 #define L2CAP_QOS	0x04
 struct l2cap_qos {
@@ -168,6 +169,7 @@ typedef struct {
 #define L2CAP_CONF_MTU		0x01
 #define L2CAP_CONF_FLUSH_TO	0x02
 #define L2CAP_CONF_QOS		0x03
+#define L2CAP_CONF_RFC_MODE	0x04
 
 #define L2CAP_CONF_MAX_SIZE	22
 
@@ -196,6 +198,14 @@ typedef struct {
 } __attribute__ ((packed)) l2cap_info_rsp;
 #define L2CAP_INFO_RSP_SIZE 4
 
+/* info type */
+#define L2CAP_IT_CL_MTU		0x0001
+#define L2CAP_IT_FEAT_MASK	0x0002
+
+/* info result */
+#define L2CAP_IR_SUCCESS	0x0000
+#define L2CAP_IR_NOTSUPP	0x0001
+
 #ifdef __cplusplus
 }
 #endif
