@@ -24,7 +24,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: rfcomm.h,v 1.10 2004/04/03 05:11:38 holtmann Exp $
+ *  $Id: rfcomm.h,v 1.12 2004/11/09 12:46:35 holtmann Exp $
  */
 
 #ifndef __RFCOMM_H
@@ -49,6 +49,15 @@ struct sockaddr_rc {
 	uint8_t		rc_channel;
 };
 
+/* RFCOMM socket options */
+#define RFCOMM_LM	0x03
+#define RFCOMM_LM_MASTER	0x0001
+#define RFCOMM_LM_AUTH		0x0002
+#define RFCOMM_LM_ENCRYPT	0x0004
+#define RFCOMM_LM_TRUSTED	0x0008
+#define RFCOMM_LM_RELIABLE	0x0010
+#define RFCOMM_LM_SECURE	0x0020
+
 /* RFCOMM TTY support */
 #define RFCOMM_MAX_DEV	256
 
