@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: bluetooth.c,v 1.23 2004/05/08 18:17:29 holtmann Exp $
+ *  $Id: bluetooth.c,v 1.26 2004/11/09 00:05:03 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -121,7 +121,7 @@ int bt_error(uint16_t code)
 		return EHOSTDOWN;
 	case HCI_AUTHENTICATION_FAILURE:
 		return EACCES;
-	case HCI_KEY_MISSING:
+	case HCI_PIN_OR_KEY_MISSING:
 		return EINVAL;
 	case HCI_MEMORY_FULL:
 		return ENOMEM;
@@ -133,19 +133,25 @@ int bt_error(uint16_t code)
 	case HCI_ACL_CONNECTION_EXISTS:
 		return EALREADY;
 	case HCI_COMMAND_DISALLOWED:
+	case HCI_TRANSACTION_COLLISION:
+	case HCI_ROLE_SWITCH_PENDING:
 		return EBUSY;
 	case HCI_REJECTED_LIMITED_RESOURCES:
-	case HCI_REJECTED_SECURITY:
 	case HCI_REJECTED_PERSONAL:
+	case HCI_QOS_REJECTED:
 		return ECONNREFUSED;
 	case HCI_HOST_TIMEOUT:
 		return ETIMEDOUT;
 	case HCI_UNSUPPORTED_FEATURE:
 	case HCI_QOS_NOT_SUPPORTED:
 	case HCI_PAIRING_NOT_SUPPORTED:
+	case HCI_CLASSIFICATION_NOT_SUPPORTED:
 	case HCI_UNSUPPORTED_LMP_PARAMETER_VALUE:
+	case HCI_PARAMETER_OUT_OF_RANGE:
+	case HCI_QOS_UNACCEPTABLE_PARAMETER:
 		return EOPNOTSUPP;
 	case HCI_INVALID_PARAMETERS:
+	case HCI_SLOT_VIOLATION:
 		return EINVAL;
 	case HCI_OE_USER_ENDED_CONNECTION:
 	case HCI_OE_LOW_RESOURCES:
@@ -155,7 +161,9 @@ int bt_error(uint16_t code)
 		return ECONNABORTED;
 	case HCI_REPEATED_ATTEMPTS:
 		return ELOOP;
+	case HCI_REJECTED_SECURITY:
 	case HCI_PAIRING_NOT_ALLOWED:
+	case HCI_INSUFFICIENT_SECURITY:
 		return EACCES;
 	case HCI_UNSUPPORTED_REMOTE_FEATURE:
 		return EPROTONOSUPPORT;
@@ -297,6 +305,8 @@ char *bt_compidtostr(int compid)
 		return "Gennum Corporation";
 	case 60:
 		return "Research In Motion";
+	case 61:
+		return "IPextreme, Inc.";
 	case 65535:
 		return "internal use";
 	default:
