@@ -25,7 +25,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: hci.c,v 1.43 2004/04/25 14:10:03 holtmann Exp $
+ *  $Id: hci.c,v 1.52 2004/11/09 22:52:42 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -173,6 +173,7 @@ static hci_map dev_flags_map[] = {
 	{ "INQUIRY", HCI_INQUIRY },
 	{ "AUTH",    HCI_AUTH    },
 	{ "ENCRYPT", HCI_ENCRYPT },
+	{ "SECMGR",  HCI_SECMGR  },
 	{ NULL }
 };
 
@@ -311,9 +312,10 @@ int hci_strtolm(char *str, unsigned int *val)
 
 /* Version mapping */
 static hci_map ver_map[] = {
-	{ "1.0b",    0x00 },
-	{ "1.1",     0x01 },
-	{ "1.2",     0x02 },
+	{ "1.0b",	0x00 },
+	{ "1.1",	0x01 },
+	{ "1.2",	0x02 },
+	{ "2.0",	0x03 },
 	{ NULL }
 };
 
@@ -536,7 +538,7 @@ int hci_devinfo(int dev_id, struct hci_dev_info *di)
 	return err;
 }
 
-int hci_devba(int dev_id, bdaddr_t *ba)
+int hci_devba(int dev_id, bdaddr_t *bdaddr)
 {
 	struct hci_dev_info di;
 
@@ -548,7 +550,7 @@ int hci_devba(int dev_id, bdaddr_t *ba)
 		return -1;
 	}
 
-	bacpy(ba, &di.bdaddr);
+	bacpy(bdaddr, &di.bdaddr);
 	return 0;
 }
 
@@ -642,7 +644,7 @@ int hci_close_dev(int dd)
 }
 
 /* HCI functions that require open device
- * dd - Device descriptor returned by hci_dev_open. */
+ * dd - Device descriptor returned by hci_open_dev. */
 
 int hci_send_cmd(int dd, uint16_t ogf, uint16_t ocf, uint8_t plen, void *param)
 {
@@ -782,14 +784,14 @@ done:
 	return 0;
 }
 
-int hci_create_connection(int dd, const bdaddr_t *ba, uint16_t ptype, uint16_t clkoffset, uint8_t rswitch, uint16_t *handle, int to)
+int hci_create_connection(int dd, const bdaddr_t *bdaddr, uint16_t ptype, uint16_t clkoffset, uint8_t rswitch, uint16_t *handle, int to)
 {
 	evt_conn_complete rp;
 	create_conn_cp cp;
 	struct hci_request rq;
 
 	memset(&cp, 0, sizeof(cp));
-	bacpy(&cp.bdaddr, ba);
+	bacpy(&cp.bdaddr, bdaddr);
 	cp.pkt_type       = ptype;
 	cp.pscan_rep_mode = 0x02;
 	cp.clock_offset   = clkoffset;
@@ -891,19 +893,19 @@ int hci_write_local_name(int dd, const char *name, int to)
 	return 0;
 }
 
-int hci_remote_name(int dd, const bdaddr_t *ba, int len, char *name, int to)
+int hci_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to)
 {
-	return hci_read_remote_name(dd, ba, len, name, to);
+	return hci_read_remote_name(dd, bdaddr, len, name, to);
 }
 
-int hci_read_remote_name(int dd, const bdaddr_t *ba, int len, char *name, int to)
+int hci_read_remote_name(int dd, const bdaddr_t *bdaddr, int len, char *name, int to)
 {
 	evt_remote_name_req_complete rn;
 	remote_name_req_cp cp;
 	struct hci_request rq;
 
 	memset(&cp, 0, sizeof(cp));
-	bacpy(&cp.bdaddr, ba);
+	bacpy(&cp.bdaddr, bdaddr);
 	cp.pscan_rep_mode = 0x02;
 
 	memset(&rq, 0, sizeof(rq));
@@ -1120,6 +1122,7 @@ int hci_write_voice_setting(int dd, uint16_t vs, int to)
 	rq.ocf    = OCF_WRITE_VOICE_SETTING;
 	rq.cparam = &cp;
 	rq.clen   = WRITE_VOICE_SETTING_CP_SIZE;
+
 	return hci_send_req(dd, &rq, to);
 }
 
@@ -1161,6 +1164,7 @@ int hci_write_current_iac_lap(int dd, uint8_t num_iac, uint8_t *lap, int to)
 	rq.ocf    = OCF_WRITE_CURRENT_IAC_LAP;
 	rq.cparam = &cp;
 	rq.clen   = WRITE_CURRENT_IAC_LAP_CP_SIZE;
+
 	return hci_send_req(dd, &rq, to);
 }
 
@@ -1171,53 +1175,88 @@ int hci_authenticate_link(int dd, uint16_t handle, int to)
 	struct hci_request rq;
 
 	cp.handle = handle;
+
 	rq.ogf    = OGF_LINK_CTL;
 	rq.ocf    = OCF_AUTH_REQUESTED;
+	rq.event  = EVT_AUTH_COMPLETE;
 	rq.cparam = &cp;
 	rq.clen   = AUTH_REQUESTED_CP_SIZE;
 	rq.rparam = &rp;
-	rq.event  = EVT_AUTH_COMPLETE;
 	rq.rlen   = EVT_AUTH_COMPLETE_SIZE;
+
 	if (hci_send_req(dd, &rq, to) < 0)
 		return -1;
+
 	if (rp.status) {
 		errno = EIO;
 		return -1;
 	}
+
 	return 0;
 }
 
-int hci_encrypt_link(int dd, uint16_t handle, int on, int to)
+int hci_encrypt_link(int dd, uint16_t handle, uint8_t encrypt, int to)
 {
 	set_conn_encrypt_cp cp;
 	evt_encrypt_change rp;
 	struct hci_request rq;
 
 	cp.handle  = handle;
-	cp.encrypt = on;
-	rq.ogf    = OGF_LINK_CTL;
-	rq.ocf    = OCF_SET_CONN_ENCRYPT;
-	rq.cparam = &cp;
-	rq.clen   = SET_CONN_ENCRYPT_CP_SIZE;
-	rq.event  = EVT_ENCRYPT_CHANGE;
-	rq.rlen   = EVT_ENCRYPT_CHANGE_SIZE;
-	rq.rparam = &rp;
+	cp.encrypt = encrypt;
+
+	rq.ogf     = OGF_LINK_CTL;
+	rq.ocf     = OCF_SET_CONN_ENCRYPT;
+	rq.event   = EVT_ENCRYPT_CHANGE;
+	rq.cparam  = &cp;
+	rq.clen    = SET_CONN_ENCRYPT_CP_SIZE;
+	rq.rparam  = &rp;
+	rq.rlen    = EVT_ENCRYPT_CHANGE_SIZE;
+
 	if (hci_send_req(dd, &rq, to) < 0)
 		return -1;
+
 	if (rp.status) {
 		errno = EIO;
 		return -1;
 	}
+
 	return 0;
 }
 
-int hci_switch_role(int dd, bdaddr_t peer, int role, int to)
+int hci_change_link_key(int dd, uint16_t handle, int to)
+{
+	change_conn_link_key_cp cp;
+	evt_change_conn_link_key_complete rp;
+	struct hci_request rq;
+
+	cp.handle = handle;
+
+	rq.ogf    = OGF_LINK_CTL;
+	rq.ocf    = OCF_CHANGE_CONN_LINK_KEY;
+	rq.event  = EVT_CHANGE_CONN_LINK_KEY_COMPLETE;
+	rq.cparam = &cp;
+	rq.clen   = CHANGE_CONN_LINK_KEY_CP_SIZE;
+	rq.rparam = &rp;
+	rq.rlen   = EVT_CHANGE_CONN_LINK_KEY_COMPLETE_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	return 0;
+}
+
+int hci_switch_role(int dd, bdaddr_t *bdaddr, uint8_t role, int to)
 {
 	switch_role_cp cp;
 	evt_role_change rp;
 	struct hci_request rq;
 
-	cp.bdaddr = peer;
+	bacpy(&cp.bdaddr, bdaddr);
 	cp.role   = role;
 	rq.ogf    = OGF_LINK_POLICY;
 	rq.ocf    = OCF_SWITCH_ROLE;
@@ -1226,12 +1265,15 @@ int hci_switch_role(int dd, bdaddr_t peer, int role, int to)
 	rq.rparam = &rp;
 	rq.rlen   = EVT_ROLE_CHANGE_SIZE;
 	rq.event  = EVT_ROLE_CHANGE;
+
 	if (hci_send_req(dd, &rq, to) < 0)
 		return -1;
+
 	if (rp.status) {
 		errno = EIO;
 		return -1;
 	}
+
 	return 0;
 }
 
@@ -1294,3 +1336,159 @@ int hci_exit_park_mode(int dd, uint16_t handle, int to)
 
 	return 0;
 }
+
+int hci_read_inquiry_mode(int dd, uint8_t *mode, int to)
+{
+	read_inquiry_mode_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_READ_INQUIRY_MODE;
+	rq.rparam = &rp;
+	rq.rlen   = READ_INQUIRY_MODE_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*mode = rp.mode;
+	return 0;
+}
+
+int hci_write_inquiry_mode(int dd, uint8_t mode, int to)
+{
+	write_inquiry_mode_cp cp;
+	write_inquiry_mode_rp rp;
+	struct hci_request rq;
+
+	memset(&cp, 0, sizeof(cp));
+	cp.mode = mode;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_WRITE_INQUIRY_MODE;
+	rq.cparam = &cp;
+	rq.clen   = WRITE_INQUIRY_MODE_CP_SIZE;
+	rq.rparam = &rp;
+	rq.rlen   = WRITE_INQUIRY_MODE_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	return 0;
+}
+
+int hci_read_afh_mode(int dd, uint8_t *mode, int to)
+{
+	read_afh_mode_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_READ_AFH_MODE;
+	rq.rparam = &rp;
+	rq.rlen   = READ_AFH_MODE_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*mode = rp.mode;
+	return 0;
+}
+
+int hci_write_afh_mode(int dd, uint8_t mode, int to)
+{
+	write_afh_mode_cp cp;
+	write_afh_mode_rp rp;
+	struct hci_request rq;
+
+	memset(&cp, 0, sizeof(cp));
+	cp.mode = mode;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_WRITE_AFH_MODE;
+	rq.cparam = &cp;
+	rq.clen   = WRITE_AFH_MODE_CP_SIZE;
+	rq.rparam = &rp;
+	rq.rlen   = WRITE_AFH_MODE_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	return 0;
+}
+
+int hci_set_afh_classification(int dd, uint8_t *map, int to)
+{
+	set_afh_classification_cp cp;
+	set_afh_classification_rp rp;
+	struct hci_request rq;
+
+	memset(&cp, 0, sizeof(cp));
+	memcpy(cp.map, map, 10);
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_HOST_CTL;
+	rq.ocf    = OCF_SET_AFH_CLASSIFICATION;
+	rq.cparam = &cp;
+	rq.clen   = SET_AFH_CLASSIFICATION_CP_SIZE;
+	rq.rparam = &rp;
+	rq.rlen   = SET_AFH_CLASSIFICATION_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	return 0;
+}
+
+int hci_read_afh_map(int dd, uint16_t handle, uint8_t *mode, uint8_t *map, int to)
+{
+	read_afh_map_rp rp;
+	struct hci_request rq;
+
+	memset(&rq, 0, sizeof(rq));
+	rq.ogf    = OGF_STATUS_PARAM;
+	rq.ocf    = OCF_READ_AFH_MAP;
+	rq.cparam = &handle;
+	rq.clen   = 2;
+	rq.rparam = &rp;
+	rq.rlen   = READ_AFH_MAP_RP_SIZE;
+
+	if (hci_send_req(dd, &rq, to) < 0)
+		return -1;
+
+	if (rp.status) {
+		errno = EIO;
+		return -1;
+	}
+
+	*mode = rp.mode;
+	memcpy(map, rp.map, 10);
+	return 0;
+}
