@@ -26,7 +26,7 @@
  *  SOFTWARE IS DISCLAIMED.
  *
  *
- *  $Id: sdp.c,v 1.6 2004/05/02 21:40:30 holtmann Exp $
+ *  $Id: sdp.c,v 1.11 2004/11/02 11:04:19 holtmann Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -74,6 +74,8 @@ static struct tupla Protocol[] = {
 	{ WSP_UUID,     "WSP"     },
 	{ BNEP_UUID,    "BNEP"    },
 	{ HIDP_UUID,    "HIDP"    },
+	{ AVCTP_UUID,   "AVCTP"   },
+	{ AVDTP_UUID,   "AVDTP"   },
 	{ CMTP_UUID,    "CMTP"    },
 	{ 0 }
 };
@@ -91,6 +93,8 @@ static struct tupla ServiceClass[] = {
 	{ IRMC_SYNC_CMD_SVCLASS_ID,     "IrMCSync Command" },
 	{ HEADSET_SVCLASS_ID,           "Headset" },
 	{ CORDLESS_TELEPHONY_SVCLASS_ID,"Cordless Telephony" },
+	{ AUDIO_SOURCE_SVCLASS_ID,      "Audio Source" },
+	{ AUDIO_SINK_SVCLASS_ID,        "Audio Sink" },
 	{ INTERCOM_SVCLASS_ID,          "Intercom" },
 	{ FAX_SVCLASS_ID,               "Fax" },
 	{ HEADSET_AGW_SVCLASS_ID,       "Headset Audio Gateway" },
@@ -104,6 +108,7 @@ static struct tupla ServiceClass[] = {
 	{ GN_SVCLASS_ID,                "PAN group network" },
 	{ HID_SVCLASS_ID,               "Human Interface Device" },
 	{ CIP_SVCLASS_ID,               "Common ISDN Access" },
+	{ SAP_SVCLASS_ID,               "SIM Access" },
 	{ 0 }
 };
 
@@ -117,14 +122,16 @@ static struct tupla Profile[] = {
 	{ IRMC_SYNC_CMD_PROFILE_ID,      "IrMCSync Command" },
 	{ HEADSET_PROFILE_ID,            "Headset" },
 	{ CORDLESS_TELEPHONY_PROFILE_ID, "Cordless Telephony" },
+	{ ADVANCED_AUDIO_PROFILE_ID,     "Advanced Audio" },
 	{ INTERCOM_PROFILE_ID,           "Intercom" },
 	{ FAX_PROFILE_ID,                "Fax" },
 	{ HEADSET_AGW_PROFILE_ID,        "Headset Audio Gateway" },
 	{ PANU_PROFILE_ID,               "PAN user" },
 	{ NAP_PROFILE_ID,                "PAN access point" },
 	{ GN_PROFILE_ID,                 "PAN group network" },
-	{ HID_SVCLASS_ID,                "Human Interface Device" },
-	{ CIP_SVCLASS_ID,                "Common ISDN Access" },
+	{ HID_PROFILE_ID,                "Human Interface Device" },
+	{ CIP_PROFILE_ID,                "Common ISDN Access" },
+	{ SAP_PROFILE_ID,                "SIM Access" },
 	{ 0 }
 };
 
@@ -481,7 +488,7 @@ void sdp_set_seq_len(char *ptr, int length)
 	case SDP_ALT32:
 	case SDP_TEXT_STR32:
 	case SDP_URL_STR32:
-		sdp_put_unaligned(htons(length), (uint32_t *)ptr);
+		sdp_put_unaligned(htonl(length), (uint32_t *)ptr);
 		break;
 	}
 }
@@ -2069,14 +2076,14 @@ int sdp_uuid128_to_uuid(uuid_t *uuid)
 	uint128_t *b = sdp_create_base_uuid();
 	uint128_t *u = &uuid->value.uuid128;
 	uint32_t data;
-	
+
 	if (uuid->type != SDP_UUID128)
 		return 1;
-	
+
 	for (i = 4; i < sizeof(b->data); i++)
 		if (b->data[i] != u->data[i])
 			return 0;
-	
+
 	memcpy(&data, u->data, 4);
 	data = htonl(data);
 	if (data <= 0xffff) {
@@ -2095,8 +2102,14 @@ int sdp_uuid128_to_uuid(uuid_t *uuid)
 int sdp_uuid_to_proto(uuid_t *uuid)
 {
 	uuid_t u = *uuid;
-	if (sdp_uuid128_to_uuid(&u) && u.type == SDP_UUID16)
-		return u.value.uuid16;
+	if (sdp_uuid128_to_uuid(&u)) {
+		switch (u.type) {
+		case SDP_UUID16:
+			return u.value.uuid16;
+		case SDP_UUID32:
+			return u.value.uuid32;
+		}
+	}
 	return 0;
 }
 
@@ -2552,11 +2565,6 @@ static int copy_cstate(char *pdata, const sdp_cstate_t *cstate)
  *     This variable is set on a successful return if there are
  *     non-zero service handles. It is a singly linked list of
  *     service records (sdp_record_t *)
- *
- *   uint16_t *handleCount
- *     This is a pointer to a 16 bit integer, which is set to 
- *     indicate the number of service record handles present in
- *     rec_list
  */
 int sdp_service_search_req(sdp_session_t *session, const sdp_list_t *search,
 			uint16_t max_rec_num, sdp_list_t **rsp)
